@@ -1,8 +1,8 @@
 use crate::error::{ErrorKind, LoftyError, Result};
 use crate::iff::chunk::Chunks;
-use crate::tag_traits::{Accessor, TagExt};
-use crate::types::item::{ItemKey, ItemValue, TagItem};
-use crate::types::tag::{Tag, TagType};
+use crate::tag::item::{ItemKey, ItemValue, TagItem};
+use crate::tag::{Tag, TagType};
+use crate::traits::{Accessor, TagExt};
 
 use std::convert::TryFrom;
 use std::fs::{File, OpenOptions};
@@ -45,6 +45,10 @@ pub struct Comment {
 ///
 /// ## Conversions
 ///
+/// ### To `Tag`
+///
+/// Items with [`ItemKey::Comment`] will be stored in the `annotations` field
+///
 /// ### From `Tag`
 ///
 /// When converting from [`Tag`](crate::Tag), the following [`ItemKey`](crate::ItemKey)s will be used:
@@ -169,6 +173,10 @@ impl TagExt for AiffTextChunks {
 	fn remove_from(&self, file: &mut File) -> std::result::Result<(), Self::Err> {
 		TagType::AiffText.remove_from(file)
 	}
+
+	fn clear(&mut self) {
+		*self = Self::default();
+	}
 }
 
 impl From<AiffTextChunks> for Tag {
@@ -206,27 +214,16 @@ impl From<AiffTextChunks> for Tag {
 
 impl From<Tag> for AiffTextChunks {
 	fn from(mut input: Tag) -> Self {
-		Self {
-			name: input.get_string(&ItemKey::TrackTitle).map(str::to_owned),
-			author: input.get_string(&ItemKey::TrackArtist).map(str::to_owned),
-			copyright: input
-				.get_string(&ItemKey::CopyrightMessage)
-				.map(str::to_owned),
-			annotations: {
-				let anno = input
-					.take(&ItemKey::Comment)
-					.filter_map(|i| match i.item_value {
-						ItemValue::Text(text) => Some(text),
-						_ => None,
-					})
-					.collect::<Vec<_>>();
+		let name = input.take_strings(&ItemKey::TrackTitle).next();
+		let author = input.take_strings(&ItemKey::TrackArtist).next();
+		let copyright = input.take_strings(&ItemKey::CopyrightMessage).next();
+		let annotations = input.take_strings(&ItemKey::Comment).collect::<Vec<_>>();
 
-				if anno.is_empty() {
-					None
-				} else {
-					Some(anno)
-				}
-			},
+		Self {
+			name,
+			author,
+			copyright,
+			annotations: (!annotations.is_empty()).then(|| annotations),
 			comments: None,
 		}
 	}
@@ -434,7 +431,7 @@ mod tests {
 			]),
 		};
 
-		let tag = crate::tag_utils::test_utils::read_path("tests/tags/assets/test.aiff_text");
+		let tag = crate::tag::utils::test_utils::read_path("tests/tags/assets/test.aiff_text");
 
 		let parsed_tag = super::super::read::read_from(&mut Cursor::new(tag), false)
 			.unwrap()
@@ -446,7 +443,7 @@ mod tests {
 
 	#[test]
 	fn aiff_text_re_read() {
-		let tag = crate::tag_utils::test_utils::read_path("tests/tags/assets/test.aiff_text");
+		let tag = crate::tag::utils::test_utils::read_path("tests/tags/assets/test.aiff_text");
 		let parsed_tag = super::super::read::read_from(&mut Cursor::new(tag), false)
 			.unwrap()
 			.text_chunks
@@ -468,7 +465,8 @@ mod tests {
 
 	#[test]
 	fn aiff_text_to_tag() {
-		let tag_bytes = crate::tag_utils::test_utils::read_path("tests/tags/assets/test.aiff_text");
+		let tag_bytes =
+			crate::tag::utils::test_utils::read_path("tests/tags/assets/test.aiff_text");
 
 		let aiff_text = super::super::read::read_from(&mut Cursor::new(tag_bytes), false)
 			.unwrap()
