@@ -5,21 +5,17 @@ use crate::ape::header::read_ape_header;
 #[cfg(feature = "ape")]
 use crate::ape::tag::read::read_ape_tag;
 use crate::error::{FileDecodingError, Result};
+use crate::file::FileType;
 #[cfg(feature = "id3v2")]
 use crate::id3::v2::read::parse_id3v2;
 use crate::id3::v2::read_id3v2_header;
 use crate::id3::{find_id3v1, find_lyrics3v2, ID3FindResults};
-use crate::types::file::FileType;
 
 use std::io::{Read, Seek, SeekFrom};
 
 use byteorder::{BigEndian, ReadBytesExt};
 
-pub(super) fn read_from<R>(
-	reader: &mut R,
-	read_tags: bool,
-	read_properties: bool,
-) -> Result<Mp3File>
+pub(super) fn read_from<R>(reader: &mut R, read_properties: bool) -> Result<Mp3File>
 where
 	R: Read + Seek,
 {
@@ -38,16 +34,14 @@ where
 		match header {
 			// [I, D, 3, ver_major, ver_minor, flags, size (4 bytes)]
 			[b'I', b'D', b'3', ..] => {
-				let mut remaining_header = [0; 6];
-				reader.read_exact(&mut remaining_header)?;
+				// Seek back to read the tag in full
+				reader.seek(SeekFrom::Current(-4))?;
 
-				let header = read_id3v2_header(
-					&mut &*[header.as_slice(), remaining_header.as_slice()].concat(),
-				)?;
+				let header = read_id3v2_header(reader)?;
 				let skip_footer = header.flags.footer;
 
 				#[cfg(feature = "id3v2")]
-				if read_tags {
+				{
 					let id3v2 = parse_id3v2(reader, header)?;
 					file.id3v2_tag = Some(id3v2);
 				}
@@ -73,7 +67,7 @@ where
 					}
 
 					#[cfg(feature = "ape")]
-					if read_tags {
+					{
 						file.ape_tag =
 							Some(crate::ape::tag::read::read_ape_tag(reader, ape_header)?);
 					}
@@ -133,7 +127,7 @@ where
 		let size = ape_header.size;
 
 		#[cfg(feature = "ape")]
-		if read_tags {
+		{
 			let ape = read_ape_tag(reader, ape_header)?;
 			file.ape_tag = Some(ape);
 		}
