@@ -5,10 +5,10 @@ pub(crate) mod write;
 
 use super::AtomIdent;
 use crate::error::{LoftyError, Result};
-use crate::tag_traits::{Accessor, TagExt};
-use crate::types::item::{ItemKey, ItemValue, TagItem};
-use crate::types::picture::{Picture, PictureType};
-use crate::types::tag::{Tag, TagType};
+use crate::picture::{Picture, PictureType};
+use crate::tag::item::{ItemKey, ItemValue, TagItem};
+use crate::tag::{Tag, TagType};
+use crate::traits::{Accessor, TagExt};
 use atom::{AdvisoryRating, Atom, AtomData, AtomDataRef, AtomIdentRef, AtomRef};
 
 use std::convert::TryInto;
@@ -250,6 +250,10 @@ impl TagExt for Ilst {
 	fn remove_from(&self, file: &mut File) -> std::result::Result<(), Self::Err> {
 		TagType::Mp4Ilst.remove_from(file)
 	}
+
+	fn clear(&mut self) {
+		self.atoms.clear();
+	}
 }
 
 impl From<Ilst> for Tag {
@@ -455,12 +459,12 @@ fn item_key_to_ident(key: &ItemKey) -> Option<AtomIdentRef<'_>> {
 #[cfg(test)]
 mod tests {
 	use crate::mp4::{AdvisoryRating, Atom, AtomData, AtomIdent, Ilst, Mp4File};
-	use crate::tag_utils::test_utils::read_path;
+	use crate::tag::utils::test_utils::read_path;
 	use crate::{Accessor, AudioFile, ItemKey, Tag, TagExt, TagType};
 	use std::io::{Cursor, Read, Seek, SeekFrom, Write};
 
 	fn read_ilst(path: &str) -> Ilst {
-		let tag = crate::tag_utils::test_utils::read_path(path);
+		let tag = crate::tag::utils::test_utils::read_path(path);
 		super::read::parse_ilst(&mut &tag[..], tag.len() as u64).unwrap()
 	}
 
@@ -523,7 +527,7 @@ mod tests {
 			AtomData::UTF8(String::from("Foo title")),
 		));
 
-		let tag = crate::tag_utils::test_utils::read_path("tests/tags/assets/ilst/test.ilst");
+		let tag = crate::tag::utils::test_utils::read_path("tests/tags/assets/ilst/test.ilst");
 
 		let parsed_tag = super::read::parse_ilst(&mut &tag[..], tag.len() as u64).unwrap();
 
@@ -546,13 +550,14 @@ mod tests {
 
 	#[test]
 	fn ilst_to_tag() {
-		let tag_bytes = crate::tag_utils::test_utils::read_path("tests/tags/assets/ilst/test.ilst");
+		let tag_bytes =
+			crate::tag::utils::test_utils::read_path("tests/tags/assets/ilst/test.ilst");
 
 		let ilst = super::read::parse_ilst(&mut &tag_bytes[..], tag_bytes.len() as u64).unwrap();
 
 		let tag: Tag = ilst.into();
 
-		crate::tag_utils::test_utils::verify_tag(&tag, true, true);
+		crate::tag::utils::test_utils::verify_tag(&tag, true, true);
 
 		assert_eq!(tag.get_string(&ItemKey::DiscNumber), Some("1"));
 		assert_eq!(tag.get_string(&ItemKey::DiscTotal), Some("2"));
@@ -560,7 +565,7 @@ mod tests {
 
 	#[test]
 	fn tag_to_ilst() {
-		let mut tag = crate::tag_utils::test_utils::create_tag(TagType::Mp4Ilst);
+		let mut tag = crate::tag::utils::test_utils::create_tag(TagType::Mp4Ilst);
 
 		tag.insert_text(ItemKey::DiscNumber, String::from("1"));
 		tag.insert_text(ItemKey::DiscTotal, String::from("2"));
@@ -690,4 +695,41 @@ mod tests {
 		file.seek(SeekFrom::Start(0)).unwrap();
 		assert!(Mp4File::read_from(&mut file, false).is_ok());
 	}
+
+	#[test]
+	fn read_non_full_meta_atom() {
+		let file_bytes = read_path("tests/files/assets/non_full_meta_atom.m4a");
+		let file = Mp4File::read_from(&mut Cursor::new(file_bytes), false).unwrap();
+
+		assert!(file.ilst.is_some());
+	}
+
+	#[test]
+	fn write_non_full_meta_atom() {
+		// This is testing writing to a file with a non-full meta atom
+		// We will *not* write a non-full meta atom
+
+		let file_bytes = read_path("tests/files/assets/non_full_meta_atom.m4a");
+		let mut file = tempfile::tempfile().unwrap();
+		file.write_all(&file_bytes).unwrap();
+		file.seek(SeekFrom::Start(0)).unwrap();
+
+		let mut tag = Ilst::default();
+		tag.insert_atom(Atom {
+			ident: AtomIdent::Fourcc(*b"\xa9ART"),
+			data: AtomData::UTF8(String::from("Foo artist")),
+		});
+
+		assert!(tag.save_to(&mut file).is_ok());
+		file.seek(SeekFrom::Start(0)).unwrap();
+
+		let mp4_file = Mp4File::read_from(&mut file, true).unwrap();
+		assert!(mp4_file.ilst.is_some());
+
+		verify_atom(
+			&mp4_file.ilst.unwrap(),
+			*b"\xa9ART",
+			&AtomData::UTF8(String::from("Foo artist")),
+		);
+	}
 }
