@@ -10,9 +10,9 @@ mod read;
 mod trak;
 
 use crate::error::Result;
-use crate::types::file::{AudioFile, FileType, TaggedFile};
-use crate::types::properties::FileProperties;
-use crate::types::tag::TagType;
+use crate::file::{AudioFile, FileType, TaggedFile};
+use crate::properties::FileProperties;
+use crate::tag::TagType;
 
 use std::io::{Read, Seek};
 
@@ -33,7 +33,7 @@ cfg_if::cfg_if! {
 	}
 }
 
-pub use crate::mp4::properties::{Mp4Codec, Mp4Properties};
+pub use crate::mp4::properties::{AudioObjectType, Mp4Codec, Mp4Properties};
 
 /// An MP4 file
 pub struct Mp4File {
