@@ -1,11 +1,12 @@
 use super::verify_signature;
 use crate::error::{ErrorKind, FileEncodingError, LoftyError, Result};
+use crate::file::FileType;
+use crate::flac;
 use crate::macros::try_vec;
 use crate::ogg::constants::{OPUSTAGS, VORBIS_COMMENT_HEAD};
 use crate::ogg::tag::{create_vorbis_comments_ref, VorbisCommentsRef};
-use crate::types::file::FileType;
-use crate::types::picture::PictureInformation;
-use crate::types::tag::{Tag, TagType};
+use crate::picture::PictureInformation;
+use crate::tag::{Tag, TagType};
 
 use std::convert::TryFrom;
 use std::fs::File;
@@ -44,8 +45,8 @@ pub(in crate) fn write_to(file: &mut File, tag: &Tag, file_type: FileType) -> Re
 				pictures,
 			};
 
-			if let FileType::FLAC = file_type {
-				return super::flac::write::write_to(file, &mut comments_ref);
+			if file_type == FileType::FLAC {
+				return flac::write::write_to(file, &mut comments_ref);
 			}
 
 			let format = match file_type {
@@ -57,6 +58,11 @@ pub(in crate) fn write_to(file: &mut File, tag: &Tag, file_type: FileType) -> Re
 
 			write(file, &mut comments_ref, format)
 		},
+		#[cfg(feature = "id3v2")]
+		TagType::Id3v2 if file_type == FileType::FLAC => {
+			// This tag can *only* be removed in this format
+			crate::id3::v2::tag::Id3v2TagRef::empty().write_to(file)
+		},
 		_ => Err(LoftyError::new(ErrorKind::UnsupportedTag)),
 	}
 }
@@ -97,7 +103,7 @@ pub(super) fn create_pages<'a, II, IP>(
 ) -> Result<Vec<Page>>
 where
 	II: Iterator<Item = (&'a str, &'a str)>,
-	IP: Iterator<Item = (&'a crate::types::picture::Picture, PictureInformation)>,
+	IP: Iterator<Item = (&'a crate::picture::Picture, PictureInformation)>,
 {
 	const PICTURE_KEY: &str = "METADATA_BLOCK_PICTURE=";
 
@@ -108,8 +114,8 @@ where
 	let mut count = 0;
 	create_comments(writer, &mut count, &mut tag.items)?;
 
-	for (pic, _) in &mut tag.pictures {
-		let picture = pic.as_flac_bytes(PictureInformation::from_picture(pic)?, true);
+	for (pic, info) in &mut tag.pictures {
+		let picture = pic.as_flac_bytes(info, true);
 
 		let bytes_len = picture.len() + PICTURE_KEY.len();
 
@@ -148,7 +154,7 @@ pub(super) fn write<'a, II, IP>(
 ) -> Result<()>
 where
 	II: Iterator<Item = (&'a str, &'a str)>,
-	IP: Iterator<Item = (&'a crate::types::picture::Picture, PictureInformation)>,
+	IP: Iterator<Item = (&'a crate::picture::Picture, PictureInformation)>,
 {
 	let first_page = Page::read(data, false)?;
 
